local toc, data = ...
local id = toc.identifier

local gadgetIndex = 0
local Sigils = {}

local iconAlpha = 70
local iconSize = 49

local iconImgSize = 48
local iconBrdrSize = 64

local borderImage = wyk.vars.Images.borders.dark.file
local borderAir = wyk.vars.Images.borders.air.file
local borderEarth = wyk.vars.Images.borders.earth.file
local borderDeath = wyk.vars.Images.borders.death.file
local borderLife = wyk.vars.Images.borders.life.file
local borderFire = wyk.vars.Images.borders.fire.file
local borderWater = wyk.vars.Images.borders.water.file
local sigilImage = wyk.vars.Images.slots.focus.file

local function round (x)
  if x >= 0 then
    return math.floor (x + 0.5)
  end  -- if positive

  return math.ceil (x - 0.5)
end

local function CheckSigil()
    local slot = Utility.Item.Slot.Equipment("focus")
    local item = Inspect.Item.Detail(slot)
    if item then
        for idx, gadget in pairs(Sigils) do
            gadget:SetAlpha(iconAlpha)
            gadget.icon:SetAlpha(iconAlpha)
            gadget.icon:SetTexture("Rift", item.icon)
            local setBorder = false
			if item.stats then
				local ar = item.stats.resistAir
				local er = item.stats.resistEarth
				local dr = item.stats.resistDeath
				local lr = item.stats.resistLife
				local fr = item.stats.resistFire
				local wr = item.stats.resistWater
				if ar ~= nil and setBorder == false then
					if ar > 60 then 
						gadget:SetTexture("libWykkyd", borderAir)
						setBorder = true
					end
				end
				if er ~= nil and setBorder == false then
					if er > 60 then 
						gadget:SetTexture("libWykkyd", borderEarth)
						setBorder = true
					end
				end
				if dr ~= nil and setBorder == false then
					if dr > 60 then 
						gadget:SetTexture("libWykkyd", borderDeath)
						setBorder = true
					end
				end
				if lr ~= nil and setBorder == false then
					if lr > 60 then 
						gadget:SetTexture("libWykkyd", borderLife)
						setBorder = true
					end
				end
				if fr ~= nil and setBorder == false then
					if fr > 60 then 
						gadget:SetTexture("libWykkyd", borderFire)
						setBorder = true
					end
				end
				if wr ~= nil and setBorder == false then
					if wr > 60 then 
						gadget:SetTexture("libWykkyd", borderWater)
						setBorder = true
					end
				end
			end
            if setBorder == false then
                gadget:SetTexture("libWykkyd", borderImage)
            end
        end
    else
        for idx, gadget in pairs(Sigils) do
            gadget:SetAlpha(iconAlpha)
            gadget.icon:SetAlpha(iconAlpha)
            gadget.icon:SetTexture("libWykkyd", sigilImage)
        end
    end
end

local started = false

local function StartUp()
    if started == false then
        CheckSigil()
        table.insert(Event.Item.Slot,{CheckSigil, "Gadgets_SigilSpy", "CheckSigil" })
        started = true
    end
end

table.insert(Event.Unit.Availability.Full, {StartUp, "Gadgets_SigilSpy", "StartUp"})


local function Create(configuration)
    iconAlpha   = (configuration.iconAlpha / 100)
    iconSize    = (configuration.iconSize / 100)
    iconImgSize = 96 * iconSize
    iconBrdrSize = 128 * iconSize
    
	local tsWrapper = wyk.frame.CreateFrame("wtSigil", WT.Context)
	tsWrapper:SetWidth(iconBrdrSize)
	tsWrapper:SetHeight(iconBrdrSize)
	tsWrapper:SetBackgroundColor(0,0,0,0.0)
    
    local tsBorder = wyk.frame.CreateTexture("wtSigil", tsWrapper)
	tsBorder:SetWidth(iconBrdrSize)
	tsBorder:SetHeight(iconBrdrSize)
    tsBorder:SetTexture("libWykkyd", borderImage)
    tsBorder:SetLayer(2)
    
	local tsIcon = wyk.frame.CreateTexture("wtSigil", tsWrapper)
	tsIcon:SetWidth(iconImgSize)
	tsIcon:SetHeight(iconImgSize)
    tsIcon:SetTexture("libWykkyd", sigilImage)
    tsIcon:SetLayer(4)
    tsBorder.icon = tsIcon
    
	tsIcon:SetPoint("CENTER", tsBorder, "CENTER", 0, 0)
	tsBorder:SetPoint("TOPCENTER", tsWrapper, "TOPCENTER", 0, 0)
        
	table.insert(Sigils, tsBorder)

	return tsWrapper
end

local dialog = false

local sldiconAlpha = nil
local sldiconSize = nil
local sldcdAlpha = nil
local sldcdFontSize = nil

local function ConfigDialog(container)
	
    local configFrame = wyk.frame.CreateFrame("ssConfig", container)
	configFrame:SetPoint("TOPLEFT", container, "TOPLEFT")
	configFrame:SetPoint("BOTTOMRIGHT", container, "BOTTOMRIGHT", 0, -32)
	
	sldiconAlpha = wyk.frame.SlideFrame("iconAlpha", configFrame, 220, {L=1,H=100}, 70, "Icon Opacity %", true)
    sldiconAlpha:SetPoint("TOPCENTER", configFrame, "TOPCENTER", 0, 16)
	
	sldiconSize = wyk.frame.SlideFrame("iconSize", configFrame, 220, {L=1,H=100}, 49, "Icon Scale", true)
    sldiconSize:SetPoint("TOPCENTER", sldiconAlpha, "BOTTOMCENTER", 0, 16)
end

local function GetConfiguration()
	local config = {
        iconAlpha = sldiconAlpha.slider:GetPosition(),
        iconSize = sldiconSize.slider:GetPosition(),
    }
    return config
end

local function SetConfiguration(config)
	sldiconAlpha.slider:SetPosition(config.iconAlpha or 75) 
	sldiconSize.slider:SetPosition(config.iconSize or 75) 
end

WT.Gadget.RegisterFactory("fsWrapper", {
		name="Sigil Spy",
		description="Sigil Spy",
		author=toc.toc.Author,
		version=toc.toc.Version,
		["Create"] = Create,
		["ConfigDialog"] = ConfigDialog,
		["GetConfiguration"] = GetConfiguration, 
		["SetConfiguration"] = SetConfiguration, 
	})
 
 